@@ -2,8 +2,9 @@
 use strict;
 use warnings;
 
-# ABSTRACT: Set up & manage a Blio instance
+# ABSTRACT: Set up & manage a Blio instance - NOT IMPLEMENTED
 # PODNAME: blio_meta.pl
+our $VERSION = '2.007'; # VERSION
 
 die "not implemented yet"
 
@@ -17,11 +18,11 @@ __END__
 
 =head1 NAME
 
-blio_meta.pl - Set up & manage a Blio instance
+blio_meta.pl - Set up & manage a Blio instance - NOT IMPLEMENTED
 
 =head1 VERSION
 
-version 2.006
+version 2.007
 
 =head1 SYNOPSIS
 
